OBJETIVO

Atendimento à demanda de fiscalização cadastrada no Fiscaliza sob a Atividade de Inspeção nº 123456, relacionada à monitoração realizada na(s) localidade(s) Salvador/BA.

INTRODUÇÃO

O Plano de Monitoração do Espectro utilizado por Aplicações Críticas (PMEC), criado no ano de 2018, tem como objetivo controlar, de forma preventiva, o uso de canais e faixas de frequência relacionados a serviços críticos, com destaque para os indicados a seguir.

- Faixa 108.000 a 118.000 MHz, destinada à radionavegação aeronáutica (incluso ILS Localizer e VOR).

- Faixa 118.000 a 137.000 MHz, destinada à radiocomunicação aeronáutica (incluso canal de emergência centralizado em 121.500 MHz).

- Faixas destinadas ao Serviço Móvel Pessoal.

- Canais internacionais de socorro e segurança destinados ao serviço móvel marítimo centralizados em 156.525 e 156.800 MHz.

- Canal centralizado em 406.000 MHz, destinado às balizas de emergência do sistema COSPAS/SARSAT.

Neste ano de 2024, o PMEC foi formalizado por meio dos Processos nºs 53500.316500/2022-18, o qual contempla o Plano de Ação de Fiscalização (SEI nº 9509939), e 53500.105183/2023-89, o qual contempla o Plano de Trabalho (SEI nº 11322780).

CONCLUSÃO

Ante o exposto, conclui-se este relatório de atividades.

_____________________________________________

appAnalise v. 1.56, fiscaliza v. 0.2.20, RFDataHub 30/11/2023 06:47:45

Relatório: {"Name":"PMEC 2024","Template":"PMEC_2024.json","Author":"Centralizador PMEC 2024","Version":"1.00","Release":"24/01/2024","RelatedServices":["010","019","230","231","507"],"JournalTable":[1,5,6,7,8,9,10,11]}

Imagem: {"Format":"jpeg","Resolution":120}

Matlab v. 23.2.0.2485118 (R2023b) Update 6 (Release date: December 28, 2023), Antenna Toolbox v. 23.2, Audio Toolbox v. 23.2, Communications Toolbox v. 23.2, Curve Fitting Toolbox v. 23.2, DSP System Toolbox v. 23.2, Database Toolbox v. 23.2, Deep Learning Toolbox v. 23.2, Image Processing Toolbox v. 23.2, Instrument Control Toolbox v. 23.2, MATLAB v. 23.2, MATLAB Compiler v. 23.2, MATLAB Report Generator v. 23.2, Mapping Toolbox v. 23.2, Optimization Toolbox v. 23.2, Parallel Computing Toolbox v. 23.2, RF Toolbox v. 23.2, Signal Processing Toolbox v. 23.2, Statistics and Machine Learning Toolbox v. 23.2, Symbolic Math Toolbox v. 23.2, Text Analytics Toolbox v. 23.2

Python v. 3.9